@@ -58,9 +58,9 @@ def varAnd(population, toolbox, cxpb, mutpb):
     mutated version in :math:`P_\mathrm{o}`. The resulting :math:`P_\mathrm{o}`
     is returned.
 
-    This variation is named *And* beceause of its propention to apply both
+    This variation is named *And* because of its propensity to apply both
     crossover and mutation on the individuals. Note that both operators are
-    not applied systematicaly, the resulting individuals can be generated from
+    not applied systematically, the resulting individuals can be generated from
     crossover only, mutation only, crossover and mutation, and reproduction
     according to the given probabilities. Both probabilities should be in
     :math:`[0, 1]`.
@@ -105,7 +105,7 @@ def eaSimple(population, toolbox, cxpb, mutpb, ngen, stats=None,
     The algorithm takes in a population and evolves it in place using the
     :meth:`varAnd` method. It returns the optimized population and a
     :class:`~deap.tools.Logbook` with the statistics of the evolution. The
-    logbook will contain the generation number, the number of evalutions for
+    logbook will contain the generation number, the number of evaluations for
     each generation and the statistics if a :class:`~deap.tools.Statistics` is
     given as argument. The *cxpb* and *mutpb* arguments are passed to the
     :func:`varAnd` function. The pseudocode goes as follow ::
@@ -201,9 +201,7 @@ def varOr(population, toolbox, lambda_, cxpb, mutpb):
     :param lambda\_: The number of children to produce
     :param cxpb: The probability of mating two individuals.
     :param mutpb: The probability of mutating an individual.
-    :returns: The final population
-    :returns: A :class:`~deap.tools.Logbook` with the statistics of the
-              evolution
+    :returns: The final population.
 
     The variation goes as follow. On each of the *lambda_* iteration, it
     selects one of the three operations; crossover, mutation or reproduction.
@@ -219,7 +217,7 @@ def varOr(population, toolbox, lambda_, cxpb, mutpb):
     selected at random from :math:`P_\mathrm{p}`, cloned and appended to
     :math:`P_\mathrm{o}`.
 
-    This variation is named *Or* beceause an offspring will never result from
+    This variation is named *Or* because an offspring will never result from
     both operations crossover and mutation. The sum of both probabilities
     shall be in :math:`[0, 1]`, the reproduction probability is
     1 - *cxpb* - *mutpb*.
@@ -271,7 +269,7 @@ def eaMuPlusLambda(population, toolbox, mu, lambda_, cxpb, mutpb, ngen,
     The algorithm takes in a population and evolves it in place using the
     :func:`varOr` function. It returns the optimized population and a
     :class:`~deap.tools.Logbook` with the statistics of the evolution. The
-    logbook will contain the generation number, the number of evalutions for
+    logbook will contain the generation number, the number of evaluations for
     each generation and the statistics if a :class:`~deap.tools.Statistics` is
     given as argument. The *cxpb* and *mutpb* arguments are passed to the
     :func:`varOr` function. The pseudocode goes as follow ::
@@ -363,7 +361,7 @@ def eaMuCommaLambda(population, toolbox, mu, lambda_, cxpb, mutpb, ngen,
     The algorithm takes in a population and evolves it in place using the
     :func:`varOr` function. It returns the optimized population and a
     :class:`~deap.tools.Logbook` with the statistics of the evolution. The
-    logbook will contain the generation number, the number of evalutions for
+    logbook will contain the generation number, the number of evaluations for
     each generation and the statistics if a :class:`~deap.tools.Statistics` is
     given as argument. The *cxpb* and *mutpb* arguments are passed to the
     :func:`varOr` function. The pseudocode goes as follow ::
@@ -460,7 +458,7 @@ def eaGenerateUpdate(toolbox, ngen, halloffame=None, stats=None,
     function and updates the generation method with the :func:`toolbox.update`
     function. It returns the optimized population and a
     :class:`~deap.tools.Logbook` with the statistics of the evolution. The
-    logbook will contain the generation number, the number of evalutions for
+    logbook will contain the generation number, the number of evaluations for
     each generation and the statistics if a :class:`~deap.tools.Statistics` is
     given as argument. The pseudocode goes as follow ::
 
