@@ -138,6 +138,6 @@ def royal_road2(individual, order):
     total = 0
     norder = order
     while norder < order**2:
-        total += royal_road1(norder, individual)[0]
+        total += royal_road1(individual, norder)[0]
         norder *= 2
     return total,
