@@ -1,11 +1,12 @@
 from __future__ import division
 import bisect
+from collections import defaultdict, namedtuple
+from itertools import chain
 import math
+from operator import attrgetter, itemgetter
 import random
 
-from itertools import chain
-from operator import attrgetter, itemgetter
-from collections import defaultdict
+import numpy
 
 ######################################
 # Non-Dominated Sorting   (NSGA-II)  #
@@ -19,12 +20,12 @@ def selNSGA2(individuals, k, nd='standard'):
     than sorting the population according to their front rank. The
     list returned contains references to the input *individuals*. For more
     details on the NSGA-II operator see [Deb2002]_.
-    
+
     :param individuals: A list of individuals to select from.
     :param k: The number of individuals to select.
     :param nd: Specify the non-dominated algorithm to use: 'standard' or 'log'.
     :returns: A list of selected individuals.
-    
+
     .. [Deb2002] Deb, Pratab, Agarwal, and Meyarivan, "A fast elitist
        non-dominated sorting genetic algorithm for multi-objective
        optimization: NSGA-II", 2002.
@@ -39,27 +40,28 @@ def selNSGA2(individuals, k, nd='standard'):
 
     for front in pareto_fronts:
         assignCrowdingDist(front)
-    
+
     chosen = list(chain(*pareto_fronts[:-1]))
     k = k - len(chosen)
     if k > 0:
         sorted_front = sorted(pareto_fronts[-1], key=attrgetter("fitness.crowding_dist"), reverse=True)
         chosen.extend(sorted_front[:k])
-        
+
     return chosen
 
+
 def sortNondominated(individuals, k, first_front_only=False):
-    """Sort the first *k* *individuals* into different nondomination levels 
+    """Sort the first *k* *individuals* into different nondomination levels
     using the "Fast Nondominated Sorting Approach" proposed by Deb et al.,
-    see [Deb2002]_. This algorithm has a time complexity of :math:`O(MN^2)`, 
-    where :math:`M` is the number of objectives and :math:`N` the number of 
+    see [Deb2002]_. This algorithm has a time complexity of :math:`O(MN^2)`,
+    where :math:`M` is the number of objectives and :math:`N` the number of
     individuals.
-    
+
     :param individuals: A list of individuals to select from.
     :param k: The number of individuals to select.
     :param first_front_only: If :obj:`True` sort only the first front and
                              exit.
-    :returns: A list of Pareto fronts (lists), the first list includes 
+    :returns: A list of Pareto fronts (lists), the first list includes
               nondominated individuals.
 
     .. [Deb2002] Deb, Pratab, Agarwal, and Meyarivan, "A fast elitist
@@ -73,12 +75,12 @@ def sortNondominated(individuals, k, first_front_only=False):
     for ind in individuals:
         map_fit_ind[ind.fitness].append(ind)
     fits = map_fit_ind.keys()
-    
+
     current_front = []
     next_front = []
     dominating_fits = defaultdict(int)
     dominated_fits = defaultdict(list)
-    
+
     # Rank first Pareto front
     for i, fit_i in enumerate(fits):
         for fit_j in fits[i+1:]:
@@ -90,13 +92,13 @@ def sortNondominated(individuals, k, first_front_only=False):
                 dominated_fits[fit_j].append(fit_i)
         if dominating_fits[fit_i] == 0:
             current_front.append(fit_i)
-    
+
     fronts = [[]]
     for fit in current_front:
         fronts[-1].extend(map_fit_ind[fit])
     pareto_sorted = len(fronts[-1])
 
-    # Rank the next front until all individuals are sorted or 
+    # Rank the next front until all individuals are sorted or
     # the given number of individual are sorted.
     if not first_front_only:
         N = min(len(individuals), k)
@@ -111,22 +113,22 @@ def sortNondominated(individuals, k, first_front_only=False):
                         fronts[-1].extend(map_fit_ind[fit_d])
             current_front = next_front
             next_front = []
-    
+
     return fronts
 
 def assignCrowdingDist(individuals):
-    """Assign a crowding distance to each individual's fitness. The 
-    crowding distance can be retrieve via the :attr:`crowding_dist` 
+    """Assign a crowding distance to each individual's fitness. The
+    crowding distance can be retrieve via the :attr:`crowding_dist`
     attribute of each individual's fitness.
     """
     if len(individuals) == 0:
         return
-    
+
     distances = [0.0] * len(individuals)
     crowd = [(ind.fitness.values, i) for i, ind in enumerate(individuals)]
-    
+
     nobj = len(individuals[0].fitness.values)
-    
+
     for i in xrange(nobj):
         crowd.sort(key=lambda element: element[0][i])
         distances[crowd[0][1]] = float("inf")
@@ -148,14 +150,21 @@ def selTournamentDCD(individuals, k):
     individuals, two consecutive individuals will be different (assuming all
     individuals in the input list are unique). Each individual from the input
     list won't be selected more than twice.
-    
+
     This selection requires the individuals to have a :attr:`crowding_dist`
     attribute, which can be set by the :func:`assignCrowdingDist` function.
-    
+
     :param individuals: A list of individuals to select from.
     :param k: The number of individuals to select.
     :returns: A list of selected individuals.
     """
+
+    if len(individuals) % 4 != 0:
+        raise ValueError("selTournamentDCD: individuals length must be a multiple of 4")
+
+    if k % 4 != 0:
+        raise ValueError("selTournamentDCD: number of individuals to select must be a multiple of 4")
+
     def tourn(ind1, ind2):
         if ind1.fitness.dominates(ind2.fitness):
             return ind1
@@ -194,7 +203,7 @@ def identity(obj):
 
 def isDominated(wvalues1, wvalues2):
     """Returns whether or not *wvalues1* dominates *wvalues2*.
-    
+
     :param wvalues1: The weighted fitness values that would be dominated.
     :param wvalues2: The weighted fitness values of the dominant.
     :returns: :obj:`True` if wvalues2 dominates wvalues1, :obj:`False`
@@ -209,8 +218,8 @@ def isDominated(wvalues1, wvalues2):
     return not_equal
 
 def median(seq, key=identity):
-    """Returns the median of *seq* - the numeric value separating the higher 
-    half of a sample from the lower half. If there is an even number of 
+    """Returns the median of *seq* - the numeric value separating the higher
+    half of a sample from the lower half. If there is an even number of
     elements in *seq*, it returns the mean of the two middle values.
     """
     sseq = sorted(seq, key=key)
@@ -224,19 +233,19 @@ def sortLogNondominated(individuals, k, first_front_only=False):
     """Sort *individuals* in pareto non-dominated fronts using the Generalized
     Reduced Run-Time Complexity Non-Dominated Sorting Algorithm presented by
     Fortin et al. (2013).
-    
+
     :param individuals: A list of individuals to select from.
     :returns: A list of Pareto fronts (lists), with the first list being the
               true Pareto front.
     """
     if k == 0:
         return []
-    
+
     #Separate individuals according to unique fitnesses
     unique_fits = defaultdict(list)
     for i, ind in enumerate(individuals):
         unique_fits[ind.fitness.wvalues].append(ind)
-    
+
     #Launch the sorting algorithm
     obj = len(individuals[0].fitness.wvalues)-1
     fitnesses = unique_fits.keys()
@@ -244,8 +253,8 @@ def sortLogNondominated(individuals, k, first_front_only=False):
 
     # Sort the fitnesses lexicographically.
     fitnesses.sort(reverse=True)
-    sortNDHelperA(fitnesses, obj, front)    
-    
+    sortNDHelperA(fitnesses, obj, front)
+
     #Extract individuals from front list here
     nbfronts = max(front.values())+1
     pareto_fronts = [[] for i in range(nbfronts)]
@@ -318,7 +327,7 @@ def sweepA(fitnesses, front):
     to the first two objectives using a geometric sweep procedure.
     """
     stairs = [-fitnesses[0][1]]
-    fstairs = [fitnesses[0]]  
+    fstairs = [fitnesses[0]]
     for fit in fitnesses[1:]:
         idx = bisect.bisect_right(stairs, -fit[1])
         if 0 < idx <= len(stairs):
@@ -333,11 +342,11 @@ def sweepA(fitnesses, front):
         fstairs.insert(idx, fit)
 
 def sortNDHelperB(best, worst, obj, front):
-    """Assign front numbers to the solutions in H according to the solutions 
-    in L. The solutions in L are assumed to have correct front numbers and the 
-    solutions in H are not compared with each other, as this is supposed to 
+    """Assign front numbers to the solutions in H according to the solutions
+    in L. The solutions in L are assumed to have correct front numbers and the
+    solutions in H are not compared with each other, as this is supposed to
     happen after sortNDHelperB is called."""
-    key = itemgetter(obj)    
+    key = itemgetter(obj)
     if len(worst) == 0 or len(best) == 0:
         #One of the lists is empty: nothing to do
         return
@@ -351,7 +360,7 @@ def sortNDHelperB(best, worst, obj, front):
         sweepB(best, worst, front)
     elif key(min(best, key=key)) >= key(max(worst, key=key)):
         #All individuals from L dominate H for objective M:
-        #Also supports the case where every individuals in L and H 
+        #Also supports the case where every individuals in L and H
         #has the same value for the current objective
         #Skip to objective M-1
         sortNDHelperB(best, worst, obj-1, front)
@@ -364,7 +373,7 @@ def sortNDHelperB(best, worst, obj, front):
 def splitB(best, worst, obj):
     """Split both best individual and worst sets of fitnesses according
     to the median of objective *obj* computed on the set containing the
-    most elements. The values equal to the median are attributed so as 
+    most elements. The values equal to the median are attributed so as
     to balance the four resulting sets as much as possible.
     """
     median_ = median(best if len(best) > len(worst) else worst, itemgetter(obj))
@@ -379,8 +388,8 @@ def splitB(best, worst, obj):
         else:
             best1_a.append(fit)
             best2_b.append(fit)
-    
-    worst1_a, worst2_a, worst1_b, worst2_b = [], [], [], []        
+
+    worst1_a, worst2_a, worst1_b, worst2_b = [], [], [], []
     for fit in worst:
         if fit[obj] > median_:
             worst1_a.append(fit)
@@ -391,7 +400,7 @@ def splitB(best, worst, obj):
         else:
             worst1_a.append(fit)
             worst2_b.append(fit)
-    
+
     balance_a = abs(len(best1_a) - len(best2_a) + len(worst1_a) - len(worst2_a))
     balance_b = abs(len(best1_b) - len(best2_b) + len(worst1_b) - len(worst2_b))
 
@@ -429,6 +438,248 @@ def sweepB(best, worst, front):
             fstair = max(fstairs[:idx], key=front.__getitem__)
             front[h] = max(front[h], front[fstair]+1)
 
+######################################
+# Non-Dominated Sorting  (NSGA-III)  #
+######################################
+
+NSGA3Memory = namedtuple("NSGA3Memory", ["best_point", "worst_point", "extreme_points"])
+
+
+class selNSGA3WithMemory(object):
+    """Class version of NSGA-III selection including memory for best, worst and
+    extreme points. Registering this operator in a toolbox is a bit different
+    than classical operators, it requires to instanciate the class instead
+    of just registering the function::
+
+        >>> from deap import base
+        >>> ref_points = uniform_reference_points(nobj=3, p=12)
+        >>> toolbox = base.Toolbox()
+        >>> toolbox.register("select", selNSGA3WithMemory(ref_points))
+
+    """
+    def __init__(self, ref_points, nd="log"):
+        self.ref_points = ref_points
+        self.nd = nd
+        self.best_point = numpy.full((1, ref_points.shape[1]), numpy.inf)
+        self.worst_point = numpy.full((1, ref_points.shape[1]), -numpy.inf)
+        self.extreme_points = None
+
+    def __call__(self, individuals, k):
+        chosen, memory = selNSGA3(individuals, k, self.ref_points, self.nd,
+                                  self.best_point, self.worst_point,
+                                  self.extreme_points, True)
+        self.best_point = memory.best_point.reshape((1, -1))
+        self.worst_point = memory.worst_point.reshape((1, -1))
+        self.extreme_points = memory.extreme_points
+        return chosen
+
+
+def selNSGA3(individuals, k, ref_points, nd="log", best_point=None,
+             worst_point=None, extreme_points=None, return_memory=False):
+    """Implementation of NSGA-III selection as presented in [Deb2014]_.
+
+    This implementation is partly based on `lmarti/nsgaiii
+    <https://github.com/lmarti/nsgaiii>`_. It departs slightly from the
+    original implementation in that it does not use memory to keep track
+    of ideal and extreme points. This choice has been made to fit the
+    functional api of DEAP. For a version of NSGA-III see
+    :class:`~deap.tools.selNSGA3WithMemory`.
+
+    :param individuals: A list of individuals to select from.
+    :param k: The number of individuals to select.
+    :param ref_points: Reference points to use for niching.
+    :param nd: Specify the non-dominated algorithm to use: 'standard' or 'log'.
+    :param best_point: Best point found at previous generation. If not provided
+        find the best point only from current individuals.
+    :param worst_point: Worst point found at previous generation. If not provided
+        find the worst point only from current individuals.
+    :param extreme_points: Extreme points found at previous generation. If not provided
+        find the extreme points only from current individuals.
+    :param return_memory: If :data:`True`, return the best, worst and extreme points
+        in addition to the chosen individuals.
+    :returns: A list of selected individuals.
+    :returns: If `return_memory` is :data:`True`, a namedtuple with the
+        `best_point`, `worst_point`, and `extreme_points`.
+
+
+    You can generate the reference points using the :func:`uniform_reference_points`
+    function::
+
+        >>> ref_points = tools.uniform_reference_points(nobj=3, p=12)   # doctest: +SKIP
+        >>> selected = selNSGA3(population, k, ref_points)              # doctest: +SKIP
+
+    .. [Deb2014] Deb, K., & Jain, H. (2014). An Evolutionary Many-Objective Optimization
+        Algorithm Using Reference-Point-Based Nondominated Sorting Approach,
+        Part I: Solving Problems With Box Constraints. IEEE Transactions on
+        Evolutionary Computation, 18(4), 577-601. doi:10.1109/TEVC.2013.2281535.
+    """
+    if nd == "standard":
+        pareto_fronts = sortNondominated(individuals, k)
+    elif nd == "log":
+        pareto_fronts = sortLogNondominated(individuals, k)
+    else:
+        raise Exception("selNSGA3: The choice of non-dominated sorting "
+                        "method '{0}' is invalid.".format(nd))
+
+    # Extract fitnesses as a numpy array in the nd-sort order
+    # Use wvalues * -1 to tackle always as a minimization problem
+    fitnesses = numpy.array([ind.fitness.wvalues for f in pareto_fronts for ind in f])
+    fitnesses *= -1
+
+    # Get best and worst point of population, contrary to pymoo
+    # we don't use memory
+    if best_point is not None and worst_point is not None:
+        best_point = numpy.min(numpy.concatenate((fitnesses, best_point), axis=0), axis=0)
+        worst_point = numpy.max(numpy.concatenate((fitnesses, worst_point), axis=0), axis=0)
+    else:
+        best_point = numpy.min(fitnesses, axis=0)
+        worst_point = numpy.max(fitnesses, axis=0)
+
+    extreme_points = find_extreme_points(fitnesses, best_point, extreme_points)
+    front_worst = numpy.max(fitnesses[:sum(len(f) for f in pareto_fronts), :], axis=0)
+    intercepts = find_intercepts(extreme_points, best_point, worst_point, front_worst)
+    niches, dist = associate_to_niche(fitnesses, ref_points, best_point, intercepts)
+
+    # Get counts per niche for individuals in all front but the last
+    niche_counts = numpy.zeros(len(ref_points), dtype=numpy.int64)
+    index, counts = numpy.unique(niches[:-len(pareto_fronts[-1])], return_counts=True)
+    niche_counts[index] = counts
+
+    # Choose individuals from all fronts but the last
+    chosen = list(chain(*pareto_fronts[:-1]))
+
+    # Use niching to select the remaining individuals
+    sel_count = len(chosen)
+    n = k - sel_count
+    selected = niching(pareto_fronts[-1], n, niches[sel_count:], dist[sel_count:], niche_counts)
+    chosen.extend(selected)
+
+    if return_memory:
+        return chosen, NSGA3Memory(best_point, worst_point, extreme_points)
+    return chosen
+
+
+def find_extreme_points(fitnesses, best_point, extreme_points=None):
+    'Finds the individuals with extreme values for each objective function.'
+    # Keep track of last generation extreme points
+    if extreme_points is not None:
+        fitnesses = numpy.concatenate((fitnesses, extreme_points), axis=0)
+
+    # Translate objectives
+    ft = fitnesses - best_point
+
+    # Find achievement scalarizing function (asf)
+    asf = numpy.eye(best_point.shape[0])
+    asf[asf == 0] = 1e6
+    asf = numpy.max(ft * asf[:, numpy.newaxis, :], axis=2)
+
+    # Extreme point are the fitnesses with minimal asf
+    min_asf_idx = numpy.argmin(asf, axis=1)
+    return fitnesses[min_asf_idx, :]
+
+
+def find_intercepts(extreme_points, best_point, current_worst, front_worst):
+    """Find intercepts between the hyperplane and each axis with
+    the ideal point as origin."""
+    # Construct hyperplane sum(f_i^n) = 1
+    b = numpy.ones(extreme_points.shape[1])
+    A = extreme_points - best_point
+    try:
+        x = numpy.linalg.solve(A, b)
+    except numpy.linalg.LinAlgError:
+        intercepts = current_worst
+    else:
+        intercepts = 1 / x
+
+        if (not numpy.allclose(numpy.dot(A, x), b) or
+                numpy.any(intercepts <= 1e-6) or
+                numpy.any((intercepts + best_point) > current_worst)):
+            intercepts = front_worst
+
+    return intercepts
+
+
+def associate_to_niche(fitnesses, reference_points, best_point, intercepts):
+    """Associates individuals to reference points and calculates niche number.
+    Corresponds to Algorithm 3 of Deb & Jain (2014)."""
+    # Normalize by ideal point and intercepts
+    fn = (fitnesses - best_point) / (intercepts - best_point)
+
+    # Create distance matrix
+    fn = numpy.repeat(numpy.expand_dims(fn, axis=1), len(reference_points), axis=1)
+    norm = numpy.linalg.norm(reference_points, axis=1)
+
+    distances = numpy.sum(fn * reference_points, axis=2) / norm.reshape(1, -1)
+    distances = distances[:, :, numpy.newaxis] * reference_points[numpy.newaxis, :, :] / norm[numpy.newaxis, :, numpy.newaxis]
+    distances = numpy.linalg.norm(distances - fn, axis=2)
+
+    # Retrieve min distance niche index
+    niches = numpy.argmin(distances, axis=1)
+    distances = distances[range(niches.shape[0]), niches]
+    return niches, distances
+
+
+def niching(individuals, k, niches, distances, niche_counts):
+    selected = []
+    available = numpy.ones(len(individuals), dtype=numpy.bool)
+    while len(selected) < k:
+        # Maximum number of individuals (niches) to select in that round
+        n = k - len(selected)
+
+        # Find the available niches and the minimum niche count in them
+        available_niches = numpy.zeros(len(niche_counts), dtype=numpy.bool)
+        available_niches[numpy.unique(niches[available])] = True
+        min_count = numpy.min(niche_counts[available_niches])
+
+        # Select at most n niches with the minimum count
+        selected_niches = numpy.flatnonzero(numpy.logical_and(available_niches, niche_counts == min_count))
+        numpy.random.shuffle(selected_niches)
+        selected_niches = selected_niches[:n]
+
+        for niche in selected_niches:
+            # Find the individuals associated with this niche
+            niche_individuals = numpy.flatnonzero(niches == niche)
+            numpy.random.shuffle(niche_individuals)
+
+            # If no individual in that niche, select the closest to reference
+            # Else select randomly
+            if niche_counts[niche] == 0:
+                sel_index = niche_individuals[numpy.argmin(distances[niche_individuals])]
+            else:
+                sel_index = niche_individuals[0]
+
+            # Update availability, counts and selection
+            available[sel_index] = False
+            niche_counts[niche] += 1
+            selected.append(individuals[sel_index])
+
+    return selected
+
+
+def uniform_reference_points(nobj, p=4, scaling=None):
+    """Generate reference points uniformly on the hyperplane intersecting
+    each axis at 1. The scaling factor is used to combine multiple layers of
+    reference points.
+    """
+    def gen_refs_recursive(ref, nobj, left, total, depth):
+        points = []
+        if depth == nobj - 1:
+            ref[depth] = left / total
+            points.append(ref)
+        else:
+            for i in range(left + 1):
+                ref[depth] = i / total
+                points.extend(gen_refs_recursive(ref.copy(), nobj, left - i, total, depth + 1))
+        return points
+
+    ref_points = numpy.array(gen_refs_recursive(numpy.zeros(nobj), nobj, p, p, 0))
+    if scaling is not None:
+        ref_points *= scaling
+        ref_points += (1 - scaling) / nobj
+
+    return ref_points
+
+
 ######################################
 # Strength Pareto         (SPEA-II)  #
 ######################################
@@ -441,11 +692,11 @@ def selSPEA2(individuals, k):
     than sorting the population according to a strength Pareto scheme. The
     list returned contains references to the input *individuals*. For more
     details on the SPEA-II operator see [Zitzler2001]_.
-    
+
     :param individuals: A list of individuals to select from.
     :param k: The number of individuals to select.
     :returns: A list of selected individuals.
-    
+
     .. [Zitzler2001] Zitzler, Laumanns and Thiele, "SPEA 2: Improving the
        strength Pareto evolutionary algorithm", 2001.
     """
@@ -455,7 +706,7 @@ def selSPEA2(individuals, k):
     strength_fits = [0] * N
     fits = [0] * N
     dominating_inds = [list() for i in xrange(N)]
-    
+
     for i, ind_i in enumerate(individuals):
         for j, ind_j in enumerate(individuals[i+1:], i+1):
             if ind_i.fitness.dominates(ind_j.fitness):
@@ -464,14 +715,14 @@ def selSPEA2(individuals, k):
             elif ind_j.fitness.dominates(ind_i.fitness):
                 strength_fits[j] += 1
                 dominating_inds[i].append(j)
-    
+
     for i in xrange(N):
         for j in dominating_inds[i]:
             fits[i] += strength_fits[j]
-    
+
     # Choose all non-dominated individuals
     chosen_indices = [i for i in xrange(N) if fits[i] < 1]
-    
+
     if len(chosen_indices) < k:     # The archive is too small
         for i in xrange(N):
             distances = [0.0] * N
@@ -485,13 +736,13 @@ def selSPEA2(individuals, k):
             kth_dist = _randomizedSelect(distances, 0, N - 1, K)
             density = 1.0 / (kth_dist + 2.0)
             fits[i] += density
-            
+
         next_indices = [(fits[i], i) for i in xrange(N)
                         if not i in chosen_indices]
         next_indices.sort()
         #print next_indices
         chosen_indices += [i for _, i in next_indices[:k - len(chosen_indices)]]
-                
+
     elif len(chosen_indices) > k:   # The archive is too large
         N = len(chosen_indices)
         distances = [[0.0] * N for i in xrange(N)]
@@ -506,7 +757,7 @@ def selSPEA2(individuals, k):
                 distances[i][j] = dist
                 distances[j][i] = dist
             distances[i][i] = -1
-        
+
         # Insert sort is faster than quick sort for short arrays
         for i in xrange(N):
             for j in xrange(1, N):
@@ -515,7 +766,7 @@ def selSPEA2(individuals, k):
                     sorted_indices[i][l] = sorted_indices[i][l - 1]
                     l -= 1
                 sorted_indices[i][l] = j
-        
+
         size = N
         to_remove = []
         while size > k:
@@ -525,32 +776,32 @@ def selSPEA2(individuals, k):
                 for j in xrange(1, size):
                     dist_i_sorted_j = distances[i][sorted_indices[i][j]]
                     dist_min_sorted_j = distances[min_pos][sorted_indices[min_pos][j]]
-                    
+
                     if dist_i_sorted_j < dist_min_sorted_j:
                         min_pos = i
                         break
                     elif dist_i_sorted_j > dist_min_sorted_j:
                         break
-            
+
             # Remove minimal distance from sorted_indices
             for i in xrange(N):
                 distances[i][min_pos] = float("inf")
                 distances[min_pos][i] = float("inf")
-                
+
                 for j in xrange(1, size - 1):
                     if sorted_indices[i][j] == min_pos:
                         sorted_indices[i][j] = sorted_indices[i][j + 1]
                         sorted_indices[i][j + 1] = min_pos
-            
+
             # Remove corresponding individual from chosen_indices
             to_remove.append(min_pos)
             size -= 1
-        
+
         for index in reversed(sorted(to_remove)):
             del chosen_indices[index]
-    
+
     return [individuals[i] for i in chosen_indices]
-    
+
 def _randomizedSelect(array, begin, end, i):
     """Allows to select the ith smallest element from array without sorting it.
     Runtime is expected to be O(n).
@@ -568,7 +819,7 @@ def _randomizedPartition(array, begin, end):
     i = random.randint(begin, end)
     array[begin], array[i] = array[i], array[begin]
     return _partition(array, begin, end)
-    
+
 def _partition(array, begin, end):
     x = array[begin]
     i = begin - 1
@@ -586,5 +837,5 @@ def _partition(array, begin, end):
             return j
 
 
-__all__ = ['selNSGA2', 'selSPEA2', 'sortNondominated', 'sortLogNondominated',
-           'selTournamentDCD']
+__all__ = ['selNSGA2', 'selNSGA3', 'selNSGA3WithMemory', 'selSPEA2', 'sortNondominated', 'sortLogNondominated',
+           'selTournamentDCD', 'uniform_reference_points']
